import Link from "next/link"
import { chapters } from "@/data/chapters"
import { notFound } from "next/navigation"
import { ArrowLeft, BookOpen, FileText, CheckCircle, Clock } from "lucide-react"
import { Progress } from "@/components/ui/progress"

// Modify the slug matching logic to be more robust with special characters
export default function ChapterPage({ params }: { params: { slug: string } }) {
  // Normalize the slug from URL by decoding and converting to lowercase
  const normalizedSlug = decodeURIComponent(params.slug).toLowerCase()
  console.log("URL slug:", normalizedSlug)

  // Find the chapter by comparing normalized slugs
  const chapter = chapters.find((c) => {
    const chapterTitle = c.chapter.split(". ")[1]
    const chapterSlug = chapterTitle
      .toLowerCase()
      .replace(/&/g, "et")
      .replace(/'/g, "-")
      .replace(/\s+/g, "-")
      .normalize("NFD")
      .replace(/[\u0300-\u036f]/g, "")
      .replace(/-+/g, "-")

    console.log(`Chapter "${chapterTitle}" -> normalized slug: "${chapterSlug}"`)

    return chapterSlug === normalizedSlug
  })

  if (!chapter) {
    console.error(`Chapter not found for slug: ${normalizedSlug}`)
    return notFound()
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <div className={`py-16 px-4 ${chapter.color || "bg-blue-100"}`}>
        <div className="container mx-auto">
          <Link href="/" className="flex items-center text-gray-700 mb-4 hover:underline">
            <ArrowLeft className="mr-2 h-4 w-4" />
            Retour à l'accueil
          </Link>

          <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
            <div>
              <h1 className="text-3xl sm:text-4xl font-bold text-gray-900 mb-2">{chapter.chapter}</h1>
              <p className="text-lg sm:text-xl text-gray-800 mb-4">{chapter.description}</p>

              <div className="flex flex-wrap items-center gap-4 mb-4">
                <div className="flex items-center">
                  <BookOpen className="h-5 w-5 text-gray-700 mr-2" />
                  <span>{chapter.lessons.length} leçons</span>
                </div>
                <div className="flex items-center">
                  <Clock className="h-5 w-5 text-gray-700 mr-2" />
                  <span>Durée estimée: {chapter.lessons.length * 15} min</span>
                </div>
              </div>
            </div>

            <div className="mt-2 md:mt-0">
              <Link
                href={`/chapitres/${params.slug}/exercices`}
                className="bg-green-600 hover:bg-green-700 text-white py-2 px-6 rounded-lg flex items-center"
              >
                <FileText className="mr-2 h-5 w-5" />
                Tous les exercices
              </Link>
            </div>
          </div>

          <div className="mt-6">
            <div className="flex justify-between text-sm mb-2">
              <span>Progression: {chapter.progress}</span>
              <span>100 %</span>
            </div>
            <Progress value={Number.parseInt(chapter.progress) || 0} className="h-3 bg-white/50" />
          </div>
        </div>
      </div>

      <div className="container mx-auto py-12 px-4">
        <div className="bg-white rounded-lg shadow-lg overflow-hidden">
          <div className="p-8">
            <h2 className="text-2xl font-bold mb-8 flex items-center">
              <BookOpen className="mr-3 h-6 w-6 text-blue-600" />
              Leçons du chapitre
            </h2>

            <div className="space-y-6">
              {chapter.lessons.map((lesson, index) => (
                <div
                  key={index}
                  className="border rounded-lg p-4 sm:p-6 hover:shadow-md transition-shadow relative overflow-hidden"
                >
                  <div className="absolute top-0 left-0 w-1 h-full bg-blue-500"></div>

                  <div className="flex flex-col md:flex-row md:justify-between md:items-start gap-4">
                    <div>
                      <div className="flex items-center mb-2">
                        <div className="w-8 h-8 rounded-full bg-blue-100 text-blue-600 flex items-center justify-center mr-3 font-semibold">
                          {index + 1}
                        </div>
                        <h3 className="text-lg sm:text-xl font-semibold">{lesson.title}</h3>
                      </div>
                      <p className="text-gray-600 ml-11">{lesson.description}</p>
                    </div>

                    <div className="flex flex-wrap gap-2 mt-3 md:mt-0 ml-11 md:ml-0">
                      <Link
                        href={lesson.link}
                        className="bg-blue-600 hover:bg-blue-700 text-white py-2 px-4 rounded-lg flex items-center text-sm"
                      >
                        <BookOpen className="mr-2 h-4 w-4" />
                        Leçon
                      </Link>

                      {lesson.Exercice && (
                        <Link
                          href={`/exercices/${lesson.Exercice}`}
                          className="bg-green-600 hover:bg-green-700 text-white py-2 px-4 rounded-lg flex items-center text-sm"
                        >
                          <FileText className="mr-2 h-4 w-4" />
                          Exercice
                        </Link>
                      )}
                    </div>
                  </div>

                  {/* Indicateur de progression */}
                  <div className="mt-4 ml-11">
                    <div className="flex items-center text-sm text-gray-500">
                      <CheckCircle className="h-4 w-4 text-green-500 mr-2" />
                      <span>Progression: 0%</span>
                    </div>
                  </div>
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>
    </div>
  )
}
